@@ -41,7 +41,9 @@ typedef struct {
 } CopySourceDialogData;
 
 static void
-show_error (CopySourceDialogData *csdd, const gchar *msg, const GError *error)
+show_error (CopySourceDialogData *csdd,
+            const gchar *msg,
+            const GError *error)
 {
 	GtkWidget *dialog;
 
@@ -59,7 +61,8 @@ struct ForeachTzidData
 };
 
 static void
-add_timezone_to_cal_cb (icalparameter *param, gpointer data)
+add_timezone_to_cal_cb (icalparameter *param,
+                        gpointer data)
 {
 	struct ForeachTzidData *ftd = data;
 	icaltimezone *tz = NULL;
@@ -118,10 +121,6 @@ dest_source_opened_cb (GObject *source_object,
 
 	csdd->dest_client = E_CAL_CLIENT (client);
 
-	e_client_utils_open_new (csdd->selected_source, csdd->obj_type, FALSE, NULL,
-		e_client_utils_authenticate_handler, csdd->parent,
-		dest_source_opened_cb, csdd);
-
 	/* check if the destination is read only */
 	if (e_client_is_readonly (E_CLIENT (csdd->dest_client))) {
 		show_error (csdd, _("Destination is read only"), NULL);
@@ -231,7 +230,9 @@ copy_source (const CopySourceDialogData *const_csdd)
  * source to copy to.
  */
 void
-copy_source_dialog (GtkWindow *parent, ESource *source, ECalClientSourceType obj_type)
+copy_source_dialog (GtkWindow *parent,
+                    ESource *source,
+                    ECalClientSourceType obj_type)
 {
 	CopySourceDialogData csdd;
 
