@@ -73,6 +73,10 @@
 
 #define d(x)
 
+#define EM_FORMAT_HTML_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), EM_TYPE_FORMAT_HTML, EMFormatHTMLPrivate))
+
 #define EFM_MESSAGE_START_ANAME "evolution#message#start"
 #define EFH_MESSAGE_START "<A name=\"" EFM_MESSAGE_START_ANAME "\"></A>"
 
@@ -1101,10 +1105,6 @@ efh_init (EMFormatHTML *efh,
 	efh->show_icon = TRUE;
 	efh->state = EM_FORMAT_HTML_STATE_NONE;
 
-	g_signal_connect_swapped (
-		efh, "notify::mark-citations",
-		G_CALLBACK (em_format_queue_redraw), NULL);
-
 	e_extensible_load_extensions (E_EXTENSIBLE (efh));
 }
 
@@ -1274,6 +1274,7 @@ em_format_html_set_mark_citations (EMFormatHTML *efh,
 	if (mark_citations)
 		efh->text_html_flags |=
 			CAMEL_MIME_FILTER_TOHTML_MARK_CITATION;
+	else
 		efh->text_html_flags &=
 			~CAMEL_MIME_FILTER_TOHTML_MARK_CITATION;
 
@@ -1923,6 +1924,8 @@ efh_text_plain (EMFormat *emf,
 	flags = efh->text_html_flags;
 
 	dw = camel_medium_get_content ((CamelMedium *) part);
+	if (!dw)
+		return;
 
 	/* Check for RFC 2646 flowed text. */
 	if (camel_content_type_is(dw->mime_type, "text", "plain")
@@ -3177,10 +3180,11 @@ efh_format_headers (EMFormatHTML *efh,
 					!photo_name && !g_ascii_strcasecmp (header->name, "From"))
 					photo_name = header->value;
 
-				if (!mailer_shown && mailer && (!g_ascii_strcasecmp (header->name, "X-Mailer") ||
-								!g_ascii_strcasecmp (header->name, "User-Agent") ||
-								!g_ascii_strcasecmp (header->name, "X-Newsreader") ||
-								!g_ascii_strcasecmp (header->name, "X-MimeOLE"))) {
+				if (!mailer_shown && mailer && (
+				    !g_ascii_strcasecmp (header->name, "X-Mailer") ||
+				    !g_ascii_strcasecmp (header->name, "User-Agent") ||
+				    !g_ascii_strcasecmp (header->name, "X-Newsreader") ||
+				    !g_ascii_strcasecmp (header->name, "X-MimeOLE"))) {
 					struct _camel_header_raw xmailer, *use_header = NULL;
 
 					if (!g_ascii_strcasecmp (header->name, "X-MimeOLE")) {
@@ -3213,8 +3217,11 @@ efh_format_headers (EMFormatHTML *efh,
 					while (*cp == ' ')
 						cp++;
 
-					face_header_value = g_base64_decode (cp, &face_header_len);
-					face_header_value = g_realloc (face_header_value, face_header_len + 1);
+					face_header_value = g_base64_decode (
+						cp, &face_header_len);
+					face_header_value = g_realloc (
+						face_header_value,
+						face_header_len + 1);
 					face_header_value[face_header_len] = 0;
 					face_decoded = TRUE;
 				/* Showing an encoded "Face" header makes little sense */
