@@ -28,7 +28,6 @@
 #include <gconf/gconf-client.h>
 
 #include <mail/e-mail-backend.h>
-#include <mail/e-mail-label-list-store.h>
 
 #include <shell/e-shell.h>
 
@@ -59,7 +58,6 @@ e_mail_shell_settings_init (EShellBackend *shell_backend)
 	EShellSettings *shell_settings;
 	EMailBackend *backend;
 	EMailSession *session;
-	gpointer object;
 
 	shell = e_shell_backend_get_shell (shell_backend);
 	shell_settings = e_shell_get_shell_settings (shell);
@@ -69,19 +67,6 @@ e_mail_shell_settings_init (EShellBackend *shell_backend)
 
 	/*** Global Objects ***/
 
-	e_shell_settings_install_property (
-		g_param_spec_object (
-			"mail-label-list-store",
-			NULL,
-			NULL,
-			E_TYPE_MAIL_LABEL_LIST_STORE,
-			G_PARAM_READWRITE));
-
-	object = e_mail_label_list_store_new ();
-	e_shell_settings_set_object (
-		shell_settings, "mail-label-list-store", object);
-	g_object_unref (object);
-
 	e_shell_settings_install_property (
 		g_param_spec_pointer (
 			"mail-session",
@@ -313,6 +298,11 @@ e_mail_shell_settings_init (EShellBackend *shell_backend)
 		MAIL_SCHEMA,
 		"composer-outlook-filenames");
 
+	e_shell_settings_install_property_for_key (
+		"composer-localized-re",
+		MAIL_SCHEMA,
+		"composer-localized-re");
+
 	e_shell_settings_install_property_for_key (
 		"composer-ignore-list-reply-to",
 		MAIL_SCHEMA,
