@@ -26,11 +26,11 @@
 #include <glib/gi18n-lib.h>
 
 #include <camel/camel.h>
+#include <libebackend/e-extensible.h>
 
 #include <e-util/e-util.h>
-#include <e-util/e-alert-dialog.h>
-#include <e-util/e-alert-sink.h>
-#include <e-util/e-extensible.h>
+#include <libevolution-utils/e-alert-dialog.h>
+#include <libevolution-utils/e-alert-sink.h>
 #include <e-util/e-plugin-ui.h>
 
 #include "e-popup-action.h"
